==> omixVizR_1.1.3.zip: omixVizR/NEWS.md <==
# omixVizR 1.1.3

+ fix: 🐛 Fix the LaTex error caused by unicode character (U+03BB) for CRAN submission.

# omixVizR 1.1.2

+ fix: 🐛 Fix the `plot_gwas_power` function to correctly handle the `sd_trait` argument for quantitative traits, ensuring accurate power calculations.

# omixVizR 1.1.1

+ feat: ✨ Extend the function `plot_gwas_power` to support both binary and continuous traits, enhancing its utility for different types of GWAS analyses.

+ perf: ✨ Support for customizable aesthetics for the QQ plot.

# omixVizR 1.1.0

+ feat: ✨ Add a new function `plot_gwas_power_bt()` to calculate and visualize GWAS statistical power.

+ docs: 📚 Update documentation of `plot_qqman`.

# omixVizR 1.0.5, v1.0.0

+ fix: 🐛 Fix color issues for significant SNPs.

+ style: ✨ Fixes for CRAN submission issues, including using tempdir() for temporary files and replacing \dontrun{} with \donttest{}.

# omixVizR 1.0.4, v0.1.3

+ fix: 🐛 Fix plot rendering issues in Jupyter Notebook.

# omixVizR 1.0.3 (2025-07-09), v0.1.2

+ style: ✨ Fixes for CRAN submission issues, including version number updates.

+ refactor: ♻️ Enhanced plot display for better compatibility with Jupyter Notebook.

# omixVizR 1.0.002 (2025-07-09), v0.1.1

+ perf: ✨ Add argument `save_plot` to control plot saving behavior.

+ style: ✨ Fixes for CRAN submission issues, including DESCRIPTION file updates and package metadata corrections.

# omixVizR 0.0.001 (2025-07-08), v0.1.0

+ feat: 🎉 Initial CRAN submission of omixVizR v0.0.001, a toolkit for omics data visualization.

==> omixVizR_1.4.0.zip: omixVizR/NEWS.md <==
# omixVizR 1.4.0

+ feat: 🎉 Add function `plot_heatmap` for generating heatmaps with hierarchical clustering.

# omixVizR 1.3.0

+ feat: 🎉 Add function `MR_2SLS` for Two-Stage Least Squares (2SLS) Mendelian Randomization analysis.

+ feat: 🎉 Add function `plot_forest` to visualize MR results in a forest plot.

+ fix: 🐛 Bug fixes.

# omixVizR 1.1.5

+ perf: ✨ Add parameter `gwas_threshold` and `label_col` to `plot_qqman` to control SNP labeling and significance threshold.

+ fix: 🔧 Improve chromosome labeling in `plot_qqman`.

# omixVizR 1.1.4

+ fix: 🔧 Improve plot title customization option in `plot_gwas_power`.

+ fix: 🔧 Improve x-axis tick mark positioning logic in `plot_gwas_power`.

# omixVizR 1.1.3

+ fix: 🐛 Fix the LaTex error caused by unicode character (U+03BB) for CRAN submission.

# omixVizR 1.1.2

+ fix: 🐛 Fix the `plot_gwas_power` function to correctly handle the `sd_trait` argument for quantitative traits, ensuring accurate power calculations.

# omixVizR 1.1.1

+ feat: ✨ Extend the function `plot_gwas_power` to support both binary and continuous traits, enhancing its utility for different types of GWAS analyses.

+ perf: ✨ Support for customizable aesthetics for the QQ plot.

# omixVizR 1.1.0

+ feat: ✨ Add a new function `plot_gwas_power_bt()` to calculate and visualize GWAS statistical power.

+ docs: 📚 Update documentation of `plot_qqman`.

# omixVizR 1.0.5, v1.0.0

+ fix: 🐛 Fix color issues for significant SNPs.

+ style: ✨ Fixes for CRAN submission issues, including using tempdir() for temporary files and replacing \dontrun{} with \donttest{}.

# omixVizR 1.0.4, v0.1.3

+ fix: 🐛 Fix plot rendering issues in Jupyter Notebook.

# omixVizR 1.0.3 (2025-07-09), v0.1.2

+ style: ✨ Fixes for CRAN submission issues, including version number updates.

+ refactor: ♻️ Enhanced plot display for better compatibility with Jupyter Notebook.

# omixVizR 1.0.002 (2025-07-09), v0.1.1

+ perf: ✨ Add argument `save_plot` to control plot saving behavior.

+ style: ✨ Fixes for CRAN submission issues, including DESCRIPTION file updates and package metadata corrections.

# omixVizR 0.0.001 (2025-07-08), v0.1.0

+ feat: 🎉 Initial CRAN submission of omixVizR v0.0.001, a toolkit for omics data visualization.
